@@ -4,7 +4,7 @@ import unittest
 
 from tempfile import mkdtemp, mkstemp
 import shutil
-from rdflib import Graph, Dataset, URIRef, BNode, plugin
+from rdflib import Dataset, URIRef, plugin
 from rdflib.graph import DATASET_DEFAULT_GRAPH_ID
 
 from nose.exc import SkipTest
@@ -22,12 +22,12 @@ from nose.exc import SkipTest
 
 # THIS WILL DELETE ALL DATA IN THE /db dataset
 
-HOST = 'http://localhost:3030'
-DB = '/db/'
+HOST = "http://localhost:3030"
+DB = "/db/"
 
 
 class DatasetTestCase(unittest.TestCase):
-    store = 'default'
+    store = "default"
     slow = True
     tmppath = None
 
@@ -35,11 +35,9 @@ class DatasetTestCase(unittest.TestCase):
         try:
             self.graph = Dataset(store=self.store)
         except ImportError:
-            raise SkipTest(
-                "Dependencies for store '%s' not available!" % self.store)
+            raise SkipTest("Dependencies for store '%s' not available!" % self.store)
         if self.store == "SQLite":
-            _, self.tmppath = mkstemp(
-                prefix='test', dir='/tmp', suffix='.sqlite')
+            _, self.tmppath = mkstemp(prefix="test", dir="/tmp", suffix=".sqlite")
         elif self.store == "SPARQLUpdateStore":
             root = HOST + DB
             self.graph.open((root + "sparql", root + "update"))
@@ -48,17 +46,17 @@ class DatasetTestCase(unittest.TestCase):
 
         if self.store != "SPARQLUpdateStore":
             self.graph.open(self.tmppath, create=True)
-        self.michel = URIRef(u'urn:michel')
-        self.tarek = URIRef(u'urn:tarek')
-        self.bob = URIRef(u'urn:bob')
-        self.likes = URIRef(u'urn:likes')
-        self.hates = URIRef(u'urn:hates')
-        self.pizza = URIRef(u'urn:pizza')
-        self.cheese = URIRef(u'urn:cheese')
+        self.michel = URIRef("urn:michel")
+        self.tarek = URIRef("urn:tarek")
+        self.bob = URIRef("urn:bob")
+        self.likes = URIRef("urn:likes")
+        self.hates = URIRef("urn:hates")
+        self.pizza = URIRef("urn:pizza")
+        self.cheese = URIRef("urn:cheese")
 
         # Use regular URIs because SPARQL endpoints like Fuseki alter short names
-        self.c1 = URIRef(u'urn:context-1')
-        self.c2 = URIRef(u'urn:context-2')
+        self.c1 = URIRef("urn:context-1")
+        self.c2 = URIRef("urn:context-2")
 
         # delete the graph for each test!
         self.graph.remove((None, None, None))
@@ -89,8 +87,10 @@ class DatasetTestCase(unittest.TestCase):
         # empty named graphs
         if self.store != "SPARQLUpdateStore":
             # added graph exists
-            self.assertEqual(set(x.identifier for x in self.graph.contexts()),
-                             set([self.c1, DATASET_DEFAULT_GRAPH_ID]))
+            self.assertEqual(
+                set(x.identifier for x in self.graph.contexts()),
+                set([self.c1, DATASET_DEFAULT_GRAPH_ID]),
+            )
 
         # added graph is empty
         self.assertEqual(len(g1), 0)
@@ -98,8 +98,10 @@ class DatasetTestCase(unittest.TestCase):
         g1.add((self.tarek, self.likes, self.pizza))
 
         # added graph still exists
-        self.assertEqual(set(x.identifier for x in self.graph.contexts()),
-                         set([self.c1, DATASET_DEFAULT_GRAPH_ID]))
+        self.assertEqual(
+            set(x.identifier for x in self.graph.contexts()),
+            set([self.c1, DATASET_DEFAULT_GRAPH_ID]),
+        )
 
         # added graph contains one triple
         self.assertEqual(len(g1), 1)
@@ -113,77 +115,119 @@ class DatasetTestCase(unittest.TestCase):
         # empty named graphs
         if self.store != "SPARQLUpdateStore":
             # graph still exists, although empty
-            self.assertEqual(set(x.identifier for x in self.graph.contexts()),
-                             set([self.c1, DATASET_DEFAULT_GRAPH_ID]))
+            self.assertEqual(
+                set(x.identifier for x in self.graph.contexts()),
+                set([self.c1, DATASET_DEFAULT_GRAPH_ID]),
+            )
 
         g.remove_graph(self.c1)
 
         # graph is gone
-        self.assertEqual(set(x.identifier for x in self.graph.contexts()),
-                         set([DATASET_DEFAULT_GRAPH_ID]))
+        self.assertEqual(
+            set(x.identifier for x in self.graph.contexts()),
+            set([DATASET_DEFAULT_GRAPH_ID]),
+        )
 
     def testDefaultGraph(self):
         # Something the default graph is read-only (e.g. TDB in union mode)
         if self.store == "SPARQLUpdateStore":
-            print("Please make sure updating the default graph "
-                  "is supported by your SPARQL endpoint")
+            print(
+                "Please make sure updating the default graph "
+                "is supported by your SPARQL endpoint"
+            )
 
         self.graph.add((self.tarek, self.likes, self.pizza))
         self.assertEqual(len(self.graph), 1)
         # only default exists
-        self.assertEqual(set(x.identifier for x in self.graph.contexts()),
-                         set([DATASET_DEFAULT_GRAPH_ID]))
+        self.assertEqual(
+            set(x.identifier for x in self.graph.contexts()),
+            set([DATASET_DEFAULT_GRAPH_ID]),
+        )
 
         # removing default graph removes triples but not actual graph
         self.graph.remove_graph(DATASET_DEFAULT_GRAPH_ID)
 
         self.assertEqual(len(self.graph), 0)
         # default still exists
-        self.assertEqual(set(x.identifier for x in self.graph.contexts()),
-                         set([DATASET_DEFAULT_GRAPH_ID]))
+        self.assertEqual(
+            set(x.identifier for x in self.graph.contexts()),
+            set([DATASET_DEFAULT_GRAPH_ID]),
+        )
 
     def testNotUnion(self):
         # Union depends on the SPARQL endpoint configuration
         if self.store == "SPARQLUpdateStore":
-            print("Please make sure your SPARQL endpoint has not configured "
-                  "its default graph as the union of the named graphs")
+            print(
+                "Please make sure your SPARQL endpoint has not configured "
+                "its default graph as the union of the named graphs"
+            )
         g1 = self.graph.graph(self.c1)
         g1.add((self.tarek, self.likes, self.pizza))
 
-        self.assertEqual(list(self.graph.objects(self.tarek, None)),
-                         [])
+        self.assertEqual(list(self.graph.objects(self.tarek, None)), [])
         self.assertEqual(list(g1.objects(self.tarek, None)), [self.pizza])
 
+    def testIter(self):
+        """PR 1382: adds __iter__ to Dataset"""
+        d = Dataset()
+        uri_a = URIRef("https://example.com/a")
+        uri_b = URIRef("https://example.com/b")
+        uri_c = URIRef("https://example.com/c")
+        uri_d = URIRef("https://example.com/d")
+
+        d.add_graph(URIRef("https://example.com/g1"))
+        d.add((uri_a, uri_b, uri_c, URIRef("https://example.com/g1")))
+        d.add(
+            (uri_a, uri_b, uri_c, URIRef("https://example.com/g1"))
+        )  # pointless addition: duplicates above
+
+        d.add_graph(URIRef("https://example.com/g2"))
+        d.add((uri_a, uri_b, uri_c, URIRef("https://example.com/g2")))
+        d.add((uri_a, uri_b, uri_d, URIRef("https://example.com/g1")))  # new, uri_d
+
+        # traditional iterator
+        i_trad = 0
+        for t in d.quads((None, None, None)):
+            i_trad += 1
+
+        # new Dataset.__iter__ iterator
+        i_new = 0
+        for t in d:
+            i_new += 1
+
+        self.assertEqual(i_new, i_trad)  # both should be 3
+
 
 # dynamically create classes for each registered Store
 
 pluginname = None
-if __name__ == '__main__':
+if __name__ == "__main__":
     if len(sys.argv) > 1:
         pluginname = sys.argv[1]
 
 tests = 0
 
 for s in plugin.plugins(pluginname, plugin.Store):
-    if s.name in ('default', 'IOMemory', 'Auditable',
-                  'Concurrent', 'SPARQLStore'):
+    if s.name in ("default", "Memory", "Auditable", "Concurrent", "SPARQLStore"):
         continue  # these are tested by default
 
     if not s.getClass().graph_aware:
         continue
 
     if s.name == "SPARQLUpdateStore":
-        from six.moves.urllib.request import urlopen
+        from urllib.request import urlopen
+
         try:
             assert len(urlopen(HOST).read()) > 0
         except:
             sys.stderr.write("No SPARQL endpoint for %s (tests skipped)\n" % s.name)
             continue
 
-    locals()["t%d" % tests] = type("%sContextTestCase" % s.name, (
-        DatasetTestCase,), {"store": s.name})
+    locals()["t%d" % tests] = type(
+        "%sContextTestCase" % s.name, (DatasetTestCase,), {"store": s.name}
+    )
     tests += 1
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
