@@ -1,9 +1,6 @@
-
 from rdflib import ConjunctiveGraph, URIRef
 import rdflib.plugin
 
-from six import b
-
 
 def testFinalNewline():
     """
@@ -12,16 +9,22 @@ def testFinalNewline():
     import sys
 
     graph = ConjunctiveGraph()
-    graph.add((URIRef("http://ex.org/a"),
-               URIRef("http://ex.org/b"),
-               URIRef("http://ex.org/c")))
+    graph.add(
+        (
+            URIRef("http://ex.org/a"),
+            URIRef("http://ex.org/b"),
+            URIRef("http://ex.org/c"),
+        )
+    )
 
     failed = set()
     for p in rdflib.plugin.plugins(None, rdflib.plugin.Serializer):
-        v = graph.serialize(format=p.name)
-        lines = v.split(b("\n"))
-        if b("\n") not in v or (lines[-1] != b('')):
+        v = graph.serialize(format=p.name, encoding="latin-1")
+        lines = v.split("\n".encode("latin-1"))
+        if b"\n" not in v or (lines[-1] != b""):
             failed.add(p.name)
+    # JSON-LD does not require a final newline (because JSON doesn't)
+    failed = failed.difference({"json-ld", "application/ld+json"})
     assert len(failed) == 0, "No final newline for formats: '%s'" % failed
 
 
@@ -29,5 +32,6 @@ if __name__ == "__main__":
 
     import sys
     import nose
+
     if len(sys.argv) == 1:
         nose.main(defaultTest=sys.argv[0])
