@@ -5,15 +5,15 @@ import rdflib
 import unittest
 
 try:
-    import os.fork
-    import os.pipe
+    from os import fork
+    from os import pipe
 except ImportError:
     from nose import SkipTest
-    raise SkipTest('No os.fork() and/or os.pipe() on this platform, skipping')
+
+    raise SkipTest("No os.fork() and/or os.pipe() on this platform, skipping")
 
 
 class TestRandomSeedInFork(unittest.TestCase):
-
     def test_bnode_id_differs_in_fork(self):
         """Checks that os.fork()ed child processes produce a
         different sequence of BNode ids from the parent process.
@@ -26,16 +26,20 @@ class TestRandomSeedInFork(unittest.TestCase):
             r = os.fdopen(r)  # turn r into a file object
             txt = r.read()
             os.waitpid(pid, 0)  # make sure the child process gets cleaned up
+            r.close()
         else:
             os.close(r)
-            w = os.fdopen(w, 'w')
+            w = os.fdopen(w, "w")
             cb = rdflib.term.BNode()
             w.write(cb)
             w.close()
             os._exit(0)
-        assert txt != str(pb1), "Parent process BNode id: " + \
-                                "%s, child process BNode id: %s" % (
-                                    txt, str(pb1))
+        assert txt != str(
+            pb1
+        ), "Parent process BNode id: " + "%s, child process BNode id: %s" % (
+            txt,
+            str(pb1),
+        )
 
 
 if __name__ == "__main__":
