@@ -1,7 +1,7 @@
 import rdflib
 from nose.tools import assert_raises
 
-data = '''<?xml version="1.0" encoding="utf-8"?>
+data = """<?xml version="1.0" encoding="utf-8"?>
 <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
     xmlns:http="http://www.w3.org/2011/http#">
 
@@ -13,9 +13,9 @@ data = '''<?xml version="1.0" encoding="utf-8"?>
     </http:HeaderElement>
 
 </rdf:RDF>
-'''
+"""
 
-data2 = '''<?xml version="1.0" encoding="utf-8"?>
+data2 = """<?xml version="1.0" encoding="utf-8"?>
 <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
     xmlns="http://www.example.org/meeting_organization#">
 
@@ -26,11 +26,11 @@ data2 = '''<?xml version="1.0" encoding="utf-8"?>
         </Location>
     </rdf:Description>
 </rdf:RDF>
-'''
+"""
 
 
 def test_broken_rdfxml():
-    #import ipdb; ipdb.set_trace()
+    # import ipdb; ipdb.set_trace()
     def p():
         rdflib.Graph().parse(data=data)
 
@@ -38,10 +38,10 @@ def test_broken_rdfxml():
 
 
 def test_parsetype_resource():
-    g = rdflib.Graph().parse(data=data2)
-    print(g.serialize(format='n3'))
+    g = rdflib.Graph().parse(data=data2, format="xml")
+    print(g.serialize(format="n3"))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     test_broken_rdfxml()
     test_parsetype_resource()
