@@ -10,7 +10,8 @@ def test_broken_add():
     nose.tools.assert_raises(AssertionError, lambda: g.addN([(1, 2, 3, g)]))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import nose
     import sys
+
     nose.main(defaultTest=sys.argv[0])
