@@ -1,17 +1,18 @@
 import unittest
 
-
 from rdflib import Graph
-from six import b
 
-graph = Graph().parse(format='n3', data="""
+graph = Graph().parse(
+    format="n3",
+    data="""
 @prefix dct: <http://purl.org/dc/terms/> .
 @prefix foaf: <http://xmlns.com/foaf/0.1/> .
 @prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
 
 <http://example.org/doc> a foaf:Document;
     dct:created "2011-03-20"^^xsd:date .
-""")
+""",
+)
 
 
 class PrefixTypesTest(unittest.TestCase):
@@ -24,11 +25,11 @@ class PrefixTypesTest(unittest.TestCase):
     """
 
     def test(self):
-        s = graph.serialize(format='n3')
+        s = graph.serialize(format="n3", encoding="latin-1")
         print(s)
-        self.assertTrue(b("foaf:Document") in s)
-        self.assertTrue(b("xsd:date") in s)
+        self.assertTrue(b"foaf:Document" in s)
+        self.assertTrue(b"xsd:date" in s)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
