@@ -1,6 +1,6 @@
 from rdflib import Graph, Literal, Variable
 
-query_tpl = '''
+query_tpl = """
 SELECT ?x (%s(?y_) as ?y) {
   VALUES (?x ?y_ ?z) {
     ("x1" undef 1)
@@ -9,7 +9,7 @@ SELECT ?x (%s(?y_) as ?y) {
     ("x2" 42    4)
   }
 } GROUP BY ?x ORDER BY ?x
-'''
+"""
 
 Y = Variable("y")
 
@@ -24,18 +24,20 @@ def template_tst(agg_func, first, second):
 
 
 def test_aggregates():
-    yield template_tst, 'SUM', Literal(0), Literal(42)
-    yield template_tst, 'MIN', None, Literal(42)
-    yield template_tst, 'MAX', None, Literal(42)
+    yield template_tst, "SUM", Literal(0), Literal(42)
+    yield template_tst, "MIN", None, Literal(42)
+    yield template_tst, "MAX", None, Literal(42)
     # yield template_tst, 'AVG', Literal(0), Literal(42)
-    yield template_tst, 'SAMPLE', None, Literal(42)
-    yield template_tst, 'COUNT', Literal(0), Literal(1)
-    yield template_tst, 'GROUP_CONCAT', Literal(''), Literal("42")
+    yield template_tst, "SAMPLE", None, Literal(42)
+    yield template_tst, "COUNT", Literal(0), Literal(1)
+    yield template_tst, "GROUP_CONCAT", Literal(""), Literal("42")
 
 
 def test_group_by_null():
     g = Graph()
-    results = list(g.query("""
+    results = list(
+        g.query(
+            """
         SELECT ?x ?y (AVG(?z) as ?az) {
             VALUES (?x ?y ?z) {
                 (1 undef 10)
@@ -46,7 +48,9 @@ def test_group_by_null():
            }
         } GROUP BY ?x ?y
         ORDER BY ?x
-    """))
+    """
+        )
+    )
     assert len(results) == 2
     assert results[0][0] == Literal(1)
     assert results[1][0] == Literal(2)
